iamai.adapter.console package
=============================

Submodules
----------

.. toctree::
   :maxdepth: 4

   iamai.adapter.console.config
   iamai.adapter.console.event
   iamai.adapter.console.message

Module contents
---------------

.. automodule:: iamai.adapter.console
   :members:
   :undoc-members:
   :show-inheritance:
